@@ -2,28 +2,32 @@ package Message::Passing::AMQP;
 use Moose ();
 use namespace::autoclean;
 
-our $VERSION = "0.001";
+our $VERSION = "0.002";
 $VERSION = eval $VERSION;
 
 1;
 
 =head1 NAME
 
-Message::Passing::AMQP - input and output logstash messages via AMQP.
+Message::Passing::AMQP - input and output message-pass messages via AMQP.
 
 =head1 SYNOPSIS
 
     # Terminal 1:
-    $ logstash --input STDIN --output AMQP --output_options '{FIXME}'
+    $ message-pass --input STDIN --output AMQP --output_options '{"exchange_name":"test"}'
     {"data":{"some":"data"},"@metadata":"value"}
 
     # Terminal 2:
-    $ logstash --output STDOUT --input AMQP --input_options '{FIXME}'
+    $ message-pass --output STDOUT --input AMQP --input_options '{"queue_name":"test","exchange_name":"test"}'
     {"data":{"some":"data"},"@metadata":"value"}
 
 =head1 DESCRIPTION
 
-A L<AnyEvent::RabbitMQ> transport for L<Message::Passing>.
+An AMQP adaptor for L<Message::Passing> for speaking to AMQP servers, for example L<RabbitMQ|http://www.rabbitmq.com/> or QPID.
+
+=head1 PROTOCOL VERSION
+
+This adaptor uses the 0.8 version of the AMQP protocol, as currently shipped with L<AnyEvent::RabbitMQ>.
 
 =head1 SEE ALSO
 
@@ -37,7 +41,6 @@ A L<AnyEvent::RabbitMQ> transport for L<Message::Passing>.
 
 =item L<AnyEvent::RabbitMQ>
 
-
 =back
 
 =head1 AUTHOR
